@@ -4,7 +4,8 @@ from .implementations import *
 
 def build_pipeline(practice: bool, solution: bool, teaching: bool,
                    remove_without_macros: bool, remove_empty: bool,
-                   strip_lines: bool, remove_trailing_lines: bool) -> Pipeline:
+                   strip_lines: bool, remove_trailing_lines: bool,
+                   embed_images: bool) -> Pipeline:
     pipeline = Pipeline()
 
     pipeline.add(RemoveCellByMacro(practice, solution, teaching, remove_without_macros))
@@ -26,4 +27,7 @@ def build_pipeline(practice: bool, solution: bool, teaching: bool,
     if remove_empty:
         pipeline.add(RemoveEmptyCell())
 
+    if embed_images:
+        pipeline.add(EmbedImages())
+
     return pipeline
